summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
authorGravatar Antti K2014-07-26 18:18:46 +0200
committerGravatar Antti K2014-07-26 18:18:46 +0200
commitb7eb2ae8cd480804e99f6bad9c456a24bafe9c45 (patch)
tree469a2bbbe9f6e5308b94fb1ace0bb7eca62d30bc
parent7bf7b120fc6c34164dfdf07938d7de58fd7f7413 (diff)
downloadxkbcat-b7eb2ae8cd480804e99f6bad9c456a24bafe9c45.tar.gz
xkbcat-b7eb2ae8cd480804e99f6bad9c456a24bafe9c45.zip
Rebrand to xkbcat
Having taken all reasonable measures to reach the author, I'll rename to avoid confusion.
-rwxr-xr-xcompile2
-rw-r--r--xkbcat.c (renamed from xspy.c)20
2 files changed, 9 insertions, 13 deletions
diff --git a/compile b/compile
index 9fde93e..5e1dc51 100755
--- a/compile
+++ b/compile
@@ -1 +1 @@
-clang -o xspy -lX11 xspy.c
+clang -o xkbcat -lX11 xkbcat.c
diff --git a/xspy.c b/xkbcat.c
index 5025a70..d8f4cb2 100644
--- a/xspy.c
+++ b/xkbcat.c
@@ -1,19 +1,17 @@
// to compile run "gcc -o xspy -lX11 xspy.c"
/*
- xspy
- Jon A. Maxwell (JAM)
- jmaxwell@acm.vt.edu
- Monitors keystrokes even the keyboard is grabbed.
-*/
+ xkbcat
+ Monitors key presses globally across X11.
+ A rather simplified version of
+ `xspy` by Jon A. Maxwell (JAM) <jmaxwell@acm.vt.edu>
+ as modified for easier physical key monitoring by Antti Korpi <an@cyan.io>.
+*/
/*
xspy polls the keyboard to determine the state of all keys on
the keyboard. By comparing results it determines which key has
- been pressed and what modifiers are in use. In this way it
- echos to the user all keystrokes typed.
-
- xspy is freely distributable, provided the source remains intact.
+ been pressed. In this way it echos to the user all physical keys typed.
*/
#include <X11/Xlib.h>
@@ -52,8 +50,6 @@ int usage() {
exit(0);
}
-
-
int main(int argc, char *argv[]) {
char *hostname=DEFAULT_DISPLAY,
*char_ptr,
@@ -1,19 +1,17 @@
-// to compile run "gcc -o xspy -lX11 xspy.c"
+// to compile run "gcc -o xkbcat -lX11 xkbcat.c"
/*